@@ -24,11 +24,11 @@ else:
 
 __all__ = (
     "GetRawMessageContentRequestRequestTypeDef",
-    "GetRawMessageContentResponseTypeDef",
-    "PutRawMessageContentRequestRequestTypeDef",
-    "RawMessageContentTypeDef",
     "ResponseMetadataTypeDef",
     "S3ReferenceTypeDef",
+    "GetRawMessageContentResponseTypeDef",
+    "RawMessageContentTypeDef",
+    "PutRawMessageContentRequestRequestTypeDef",
 )
 
 GetRawMessageContentRequestRequestTypeDef = TypedDict(
@@ -38,29 +38,6 @@ GetRawMessageContentRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetRawMessageContentResponseTypeDef = TypedDict(
-    "GetRawMessageContentResponseTypeDef",
-    {
-        "messageContent": StreamingBody,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-PutRawMessageContentRequestRequestTypeDef = TypedDict(
-    "PutRawMessageContentRequestRequestTypeDef",
-    {
-        "messageId": str,
-        "content": "RawMessageContentTypeDef",
-    },
-)
-
-RawMessageContentTypeDef = TypedDict(
-    "RawMessageContentTypeDef",
-    {
-        "s3Reference": "S3ReferenceTypeDef",
-    },
-)
-
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -90,3 +67,27 @@ _OptionalS3ReferenceTypeDef = TypedDict(
 
 class S3ReferenceTypeDef(_RequiredS3ReferenceTypeDef, _OptionalS3ReferenceTypeDef):
     pass
+
+
+GetRawMessageContentResponseTypeDef = TypedDict(
+    "GetRawMessageContentResponseTypeDef",
+    {
+        "messageContent": StreamingBody,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RawMessageContentTypeDef = TypedDict(
+    "RawMessageContentTypeDef",
+    {
+        "s3Reference": S3ReferenceTypeDef,
+    },
+)
+
+PutRawMessageContentRequestRequestTypeDef = TypedDict(
+    "PutRawMessageContentRequestRequestTypeDef",
+    {
+        "messageId": str,
+        "content": RawMessageContentTypeDef,
+    },
+)
